#!/bin/sh

PKGBASE=$(cat NAME)
VERSION=$(cat VERSION)
PKGNAME=$PKGBASE-$VERSION
CTRLFILE=control
LICENSE="/usr/share/doc/$PKGNAME/COPYING"
README="/usr/share/doc/$PKGNAME/README"
MAINTAINER=$(cat $CTRLFILE | egrep '^%vendor' | sed 's/%vendor //')

echo "*** creating debian package ***"
CWD=$(pwd)
TMPDIR=/tmp/$PKGNAME
TMPFILE="$TMPDIR/$PKGNAME.tmp"
ARCH=$(dpkg --print-architecture)
rm -rf $TMPDIR

echo "*** building source ***"
rm -rf $TMPDIR &&
mkdir $TMPDIR &&
./autogen.sh &&
./configure --prefix=$TMPDIR/build &&
make all install &&
echo "*** source built ok ***" || {
	echo "*** error building source ***"
	exit 1
}
# fix paths
STRING=$(echo "$TMPDIR/build" | sed 's/\//\\\//g')
for i in lib/pkgconfig/$PKGBASE.pc lib/lib$PKGBASE.la
do
	cat $TMPDIR/build/$i | sed "s/$STRING/\/usr/g" > $TMPFILE
	mv $TMPFILE $TMPDIR/build/$i
done

LASTVERSION=$(echo $VERSION | cut -f 3 -d '.')
LASTVERSION=$(echo "${LASTVERSION}-1" | bc)
LASTVERSION="$(echo $VERSION | cut -f1,2 -d '.').${LASTVERSION}"
# create control file
echo "*** creating deb ***"
# create control file header
cp $CTRLFILE $TMPDIR/$PKGNAME.list
cat << EOF >> $TMPDIR/$PKGNAME.list
%product $PKGNAME
%copyright $LICENSE
%version $VERSION
%readme $README
%replaces ${PKGBASE}-${LASTVERSION}
EOF

# create filelist
mkepmlist -g root -u root --prefix /usr $TMPDIR/build >> $TMPDIR/$PKGNAME.list &&
cd $TMPDIR &&
epm -a $ARCH --output-dir . -v -f deb -n $PKGNAME &&
mv ${PKGNAME}-$VERSION.deb $CWD/${PKGNAME}_${VERSION}_$ARCH.deb &&
cd $CWD &&
echo "*** binary package build ok ***" || {
	echo "*** error creating binary package ***"
	exit 1
}

# make source package
make dist &&
cd $TMPDIR &&
tar -xzvf $CWD/$PKGBASE-$VERSION.tar.gz &&
mv $PKGBASE-$VERSION $PKGBASE-$VERSION-$VERSION
cd $PKGBASE-$VERSION-$VERSION &&
dpkg -e $CWD/${PKGNAME}_${VERSION}_$ARCH.deb &&
mv DEBIAN debian &&
cat debian/control | egrep '(^Package)|(^Maintainer)|(^Description)' > debian/1 &&
mv debian/1 debian/control &&
cat << EOF >> debian/control
Source: $PKGNAME
Architecture: any
Section: science
Priority: optional
EOF
cat << EOF > debian/changelog
$PKGNAME ($VERSION) unstable; urgency=low
  * comment here.

 -- $MAINTAINER  $(date '+%a, %d %b %Y %T %z')
EOF
cd $TMPDIR &&
dpkg-source -b $PKGBASE-$VERSION-$VERSION &&
mv $PKGBASE-${VERSION}_$VERSION.tar.gz $PKGBASE-${VERSION}_$VERSION.dsc $CWD/ &&
cd $CWD &&
echo "*** source package build ok ***" || {
	echo "*** error creating source package ***"
	exit 1
}

# make meta package
# create control file
mkdir -p $TMPDIR/$PKGBASE/DEBIAN
cat << EOF > $TMPDIR/$PKGBASE/DEBIAN/control
Package: $PKGBASE
Version: $VERSION
Section: science
Priority: optional
Architecture: all
Depends: $PKGNAME
Replaces: $PKGBASE (<< $VERSION)
EOF
cat $CTRLFILE | egrep '^%vendor' | sed 's/%vendor/Maintainer:/' >> $TMPDIR/$PKGBASE/DEBIAN/control
cat $CTRLFILE | egrep '^%description' | sed 's/%description/Description:/' >> $TMPDIR/$PKGBASE/DEBIAN/control

# make meta package
cd $TMPDIR &&
dpkg-deb --build $PKGBASE &&
mv $PKGBASE.deb $CWD/${PKGBASE}_${VERSION}_all.deb &&
cd $CWD &&
echo "*** meta package build ok ***" || {
	echo "*** error creating meta package ***"
	exit 1
}

echo "*** creating python debian package ***"

PYPKGNAME=python-${PKGNAME}
PYPKGBASE=python-${PKGBASE}
PYDEPS="libboost-python1.40.0"

cd ${CWD}/python &&
# debian control files
rm -rf debian &&
mkdir debian &&
# changelog
cat << EOF > debian/changelog &&
$PYPKGNAME ($VERSION) unstable; urgency=low
  * comment here.

 -- $MAINTAINER  $(date '+%a, %d %b %Y %T %z')
EOF
# compat
echo $(dpkg -p debhelper | egrep '^Version:' | cut -f 2 -d ' ' | cut -f 1 -d '.') > debian/compat &&
# control
cat << EOF > debian/control &&
Source: ${PYPKGNAME}
Section: science
Priority: optional
Maintainer: ${MAINTAINER}
Build-Depends: debhelper (>=7.0.0), python-support (>= 0.6), cdbs (>= 0.4.49)
Standards-Version: 3.8.3.0

Package: ${PYPKGNAME}
Architecture: ${ARCH}
Depends: \${misc:Depends}, \${python:Depends}, ${PKGNAME}, ${PYDEPS}
Description: ${PKGNAME} python bindings.
EOF
# copyright
cp ../COPYING debian/copyright &&
# rules
cat << EOF > debian/rules &&
#!/usr/bin/make -f
# -*- makefile -*-

DEB_PYTHON_SYSTEM := pysupport

include /usr/share/cdbs/1/rules/debhelper.mk
include /usr/share/cdbs/1/class/python-distutils.mk
include /usr/share/cdbs/1/rules/simple-patchsys.mk
EOF
chmod a+x debian/rules &&
# pyversion
echo "2.5" > debian/pyversions &&
# shlibs.local
LIBFILE=$(whereis libecsb | sed 's/\ /\n/g' | egrep "\.so$")
for i in $(ldd ${LIBFILE} | sed 's/^\t//g' | cut -f 1 -d ' ' | sed 's/\.so\.[0-9\.]*$//g')
do
	echo "libecsb 0 $(basename $i)," >> debian/shlibs.local
done &&
LIBFILE=$(whereis libmcss | sed 's/\ /\n/g' | egrep "\.so$")
for i in $(ldd ${LIBFILE} | sed 's/^\t//g' | cut -f 1 -d ' ' | sed 's/\.so\.[0-9\.]*$//g')
do
	echo "libmcss 0 $(basename $i)," >> debian/shlibs.local
done &&
LIBSBML=$(whereis libsbml | sed 's/\ /\n/g' | egrep "\.so$")
for i in $(ldd ${LIBFILE} | sed 's/^\t//g' | cut -f 1 -d ' ' | sed 's/\.so\.[0-9\.]*$//g')
do
	echo "libsbml 4 $(basename $i)," >> debian/shlibs.local
done &&

# make package
cd .. &&
./configure --enable-python=yes &&
cd python &&
make &&
python setup.py sdist --dist-dir=../ &&
dpkg-buildpackage -uc -b -rfakeroot &&
cd ${CWD} &&

# remove tmp files
rm -rf $TMPDIR &&

echo "*** making python meta package ***" &&

# make meta package
# create control file
mkdir -p $TMPDIR/$PYPKGBASE/DEBIAN &&
cat << EOF > $TMPDIR/$PYPKGBASE/DEBIAN/control &&
Package: $PYPKGBASE
Version: $VERSION
Section: science
Priority: optional
Architecture: all
Depends: $PYPKGNAME
Replaces: $PYPKGBASE (<< $VERSION)
EOF
cat $CTRLFILE | egrep '^%vendor' | sed 's/%vendor/Maintainer:/' >> $TMPDIR/$PYPKGBASE/DEBIAN/control &&
cat $CTRLFILE | egrep '^%description' | sed 's/%description/Description:/' >> $TMPDIR/$PYPKGBASE/DEBIAN/control &&

# make meta package
cd $TMPDIR &&
dpkg-deb --build $PYPKGBASE &&
mv $PYPKGBASE.deb $CWD/${PYPKGBASE}_${VERSION}_all.deb &&
cd $CWD &&

# remove tmp files
rm -rf $TMPDIR &&

# all done
echo "*** python package all built ok ***" ||
echo "*** error building python package ***"
