// lattice class definitions
// copyright 2008, 2009 jamie twycross, jpt AT cs.nott.ac.uk
// released under GNU GPL version 3

#ifndef LATTICE_H
#define LATTICE_H

namespace Simulation {

// lattice site structure
typedef struct LatticeSite {
	unsigned long x;
	unsigned long y;
	unsigned long z;
	unsigned long spin;
	unsigned long type;
} LatticeSite;

// lattice class
class Lattice {
	unsigned long xdim, ydim, zdim;  // lattice dimensions
	LatticeSite ****lattice;  // lattice
	unsigned int neighbourhood_size;  // number of site neighbours
	int *nxvector, *nyvector, *nzvector;  // vectors to calculate neighbours
	double site_volume;  // volume of single lattice site
	double scale;  // scale of lattice
	double temperature;  // lattice temperature

	// temporary storage for site neighbours
	unsigned int num_neighbours;
	LatticeSite **neighbours;

	public:
		// constructor
		Lattice(unsigned long x, unsigned long y, unsigned long z = 1, \
				double s = 1.0);

		// destructor
		~Lattice();

		// get size of lattice neighbourhood
		unsigned int getNeighbourhoodSize(void);

		// get volume of a single lattice site
		double getSiteVolume();

		// set lattice temperature
		void setTemperature(double);

		// get lattice temperature
		double getTemperature(void);

		// get random site on lattice
		LatticeSite *getRandomSite(void);

		// calculate list of alien neighbours i.e. with different spin
		unsigned int calculateAlienNeighbours(LatticeSite *);

		// select random alien neighbour (use after calculateAlienNeighbours)
		LatticeSite *selectAlienNeighbour(void);

		// calculate energy to flip to one spin from another
		double calculateFlipEnergy(LatticeSite *from, LatticeSite *to);

		// flip site from one spin to another
		void flipSite(LatticeSite *from, LatticeSite *to);

		// initialise lattice from p system
		double initialise(class Psystem *);
};

}

#endif
