// ruleset class definitions
// copyright 2008, 2009 jamie twycross, jpt AT cs.nott.ac.uk
// released under GNU GPL version 3

#ifndef RULESET_H
#define RULESET_H

#include "Rule.h"

#include <string>

namespace Simulation {

class RuleSet {
		unsigned long num_rules;  // number of rules in set
		class Rule **rule;  // list of rules
		std::string id;  // id of template compartment to which ruleset belongs
		std::string name;  // name of compartment to which ruleset belongs
		unsigned long index;  // index of template compartment
		double *acum;  // cumulative propensities
		bool density_ruleset;  // flag indicating if defines species density
		bool growth_ruleset;  // flag indicating if defines growth rule
		double volume;  // volume for growth rule
		unsigned long num_child_rulesets;  // number of child rulesets
		unsigned long *child_ruleset;  // list of child ruleset indices
		bool enclosed_compartment;  // flag indicating if enclosed compartment
		std::string parent_name;  // name of parent compartment

	public:
		// constructor
		RuleSet();

		// constructor
		RuleSet(const unsigned long);

		// destructor
		~RuleSet();
		
		// general access methods
		unsigned long getNumRules(void);
		Rule::Rule *getRule(const unsigned long);
		void setRule(const unsigned long, Rule::Rule *);
		std::string getId(void);
		void setId(std::string);
		std::string getName(void);
		void setName(std::string);
		const unsigned long getIndex(void);
		void setIndex(const unsigned long);
		void show(void);
		double *getCumulativePropensities(void);
		unsigned long getReactantIndex(unsigned long, unsigned long);
		unsigned long getProductIndex(unsigned long, unsigned long);
		int isChannel(unsigned long);
		const char *getRuleName(unsigned long);
		unsigned long getNumReactants(unsigned long);
		unsigned long getNumProducts(unsigned long);
		double getPropensity(unsigned long);
		long int getRuleXVector(unsigned long);
		long int getRuleYVector(unsigned long);
		long int getRuleZVector(unsigned long);
		void setDensityRuleSet(bool);
		bool isDensityRuleSet(void);
		void setGrowthRuleSet(bool);
		bool isGrowthRuleSet(void);
		void setVolume(double);
		double getVolume(void);
		unsigned long getNumChildRuleSets(void);
		void setNumChildRuleSets(unsigned long);
		unsigned long *getChildRuleSets(void);
		unsigned long getChildRuleSet(unsigned long);
		void setChildRuleSet(unsigned long, unsigned long);
		void setInitialReactant(unsigned long, unsigned long, unsigned long);
		unsigned long getInitialReactant(unsigned long, unsigned long);
		void setInitialProduct(unsigned long, unsigned long, unsigned long);
		unsigned long getInitialProduct(unsigned long, unsigned long);
		bool isEnclosedCompartment(void);
		void setEnclosedCompartment(bool);
		std::string getParentCompartmentName(void);
		void setParentCompartmentName(std::string);
		
		// append rule to a ruleset
		unsigned long addRule(Rule *r);
};

}

#endif
