# -*- coding: utf-8 -*-

import os, sys
from os.path import join as pj
from setuptools import setup, find_packages
from distutils.sysconfig import get_python_lib
from shutil import rmtree

name = 'mcss'
packagename = 'mcss'
version = "0.0.31"
description = 'multicompartment stochastic simulator',
long_description = """Python API for multicompartment stochastic simulator (mcss)"""
authors = 'Jamie Twycross',
author_email = 'jpt@cs.nott.ac.uk'
url = 'http://cs.nott.ac.uk/~jpt'
license = 'GNU GPL version 3'

def is_system_wide_install():
	return os.access(get_python_lib(), os.W_OK)

def get_root():
	try:
		return sys.argv[sys.argv.index("--root") + 1]
	except ValueError:
		return ""

def pre_install():
	if not is_system_wide_install():
		sys.argv.extend(["--prefix", "/usr/local"])

def uninstall():
	if is_system_wide_install():
		prefix = None
	else:
		prefix = "/usr/local"
	egg_name = "%s-%s-py%s.egg" % (packagename,"*",sys.version[:3])
	file = get_root() + "/" + get_python_lib(prefix=prefix) + "/" + egg_name
	rmtree(file, ignore_errors=True)
	sys.exit(0)

commands = {
	"install": pre_install,
	"uninstall": uninstall,
	}

if len(sys.argv) > 1 and commands.has_key(sys.argv[1]):
	commands[sys.argv[1]]()

setup(
	name=name,
	version=version,
	author=authors,
	author_email=author_email,
	description=description,
	long_description=long_description,
	url=url,
	license=license,
	packages=[packagename],
	include_package_data=True,
	package_data = {'' : ['*.pyd', '*.so', '*.dylib'],},
	zip_safe = False,
	)
