// single run levels (multigraph)

// parameters
//		MINTIME - set x axis start time (same units as xscale)
//		MAXTIME - set x axis end time (same units as xscale)
//		AVERAGES - plot averages
//		WIDTH - width of graph
//		HEIGHT - height of graph
//		YLABEL - set label of y axis (use underscores for spaces)
//		YLABELDISTANCE - distance of y axis label from axis
//		TITLE - set title of graph (use underscores for spaces)
//		SD - plot standard deviations
//		XSCALE=[S|M|H] - set units (seconds|minutes|hours) of x axis
//		XTICINC - set increment for x tics
//		SAMPLE - sample time every given interval

// graph width
#if $def(WIDTH) = 0
	#set WIDTH = 8.5
#endif
// graph height
#if $def(HEIGHT) = 0
	#set HEIGHT = 11
#endif
// graph border
#set YBORDER = 0.5
// label for y axis
#if $def(YLABEL) = 0
	#if $def(AVERAGES) = 1
		#set YLABEL = "mean level (molecules)"
	#else	
		#set YLABEL = "level (molecules)"
	#endif
#endif
// distance of label from y axis
#if $def(YLABELDISTANCE) = 0
	#set YLABELDISTANCE = 0.15
#endif
// standard deviations
#if $def(SD) = 0
	#set SD = 1
#endif
// graph title
#if $def(TITLE) = 0
	#set TITLE = ""
#endif
// replace underscores by spaces in strings
#set TITLE = $change("_"," ",@TITLE)
#set YLABEL = $change("_"," ",@YLABEL)
// units for time axis (S/M/H)
#if $def(XSCALE) = 0
	#set XSCALE = S
#endif
// set time scale
#if @XSCALE = H
	#set XUNITS = "hours"
	#set TF = 3600
	#if $def(SAMPLE) = 1
		#set SAMPLE = $arith(@SAMPLE*3600)
	#endif
#elseif @XSCALE = M
	#set XUNITS = "minutes"
	#set TF = 60
	#if $def(SAMPLE) = 1
		#set SAMPLE = $arith(@SAMPLE*60)
	#endif
#else
	#set XUNITS = "seconds"
	#set TF = 1
#endif


#proc page
	pagesize: @WIDTH @HEIGHT

#proc settings
	encodenames: yes

#proc getdata
	standardinput: yes
	fieldnameheader: yes
	#if $def(SAMPLE) = 1
		select: $math(mod,@@1,@SAMPLE) = 0
	#endif

#proc endproc
	#set NGRAPHS = $arith(@NFIELDS-1)
	#if $def(AVERAGES) = 1
		#set NGRAPHS = $arith(@NGRAPHS/3)
	#endif
	#set GHEIGHT = $arith(@YBORDER*2)
	#set GHEIGHT = $arith(@HEIGHT-@GHEIGHT)
	#set GHEIGHT = $arith(@GHEIGHT/@NGRAPHS)
	#if $def(MINTIME) = 0
		#set MINTIME = $dataitem(1,1)
	#else
		#set MINTIME = $arith(@MINTIME*@TF)
	#endif
	#if $def(MAXTIME) = 0
		#set MAXTIME = $dataitem(@NRECORDS,1)
	#else
		#set MINTIME = $arith(@MAXTIME*@TF)
	#endif

// set x axis stubs
#if $def(XTICINC) = 0
	#set TINK = $defaultinc(@MINTIME,@MAXTIME)
	#set TINKREM = $math(mod,@TINK,@TF)
	#set TINK = $arith(@TINK-@TINKREM)
#else
	#set TINK = $arith(@XTICINC*@TF)
#endif
#set XINC = @MINTIME
#set XTICS = ""
#while @XINC <= @MAXTIME
	#set ST = $arith(@XINC/@TF)
	#set XTIC = "@XINC @ST\\n"
	#set XTIC = $expand(@XTIC)
	#set XTICS = $strcat(@XTICS,@XTIC)
	#set XINC = $arith(@XINC+@TINK)
#endloop

#set GRAPH = 1
#set FIELD = $arith(@GRAPH+1)
#while @GRAPH <= @NGRAPHS

#set Y1 = $arith(@GRAPH-1)
#set Y1 = $arith(@Y1*@GHEIGHT)
#set Y1 = $arith(@Y1+@YBORDER)
#set Y2 = $arith(@Y1+@GHEIGHT)
#if $def(AVERAGES) = 1
	#set TITLE = $fieldname(@FIELD)
	#set INDEX = $len(@TITLE)
	#set INDEX = $arith(@INDEX-5)
	#set TITLE = $substring(@TITLE,1,@INDEX)
#else
	#set TITLE = $fieldname(@FIELD)
#endif
#if $def(AVERAGES) = 1
	#set LOWFIELD = $arith(@FIELD+1)
	#set HIGHFIELD = $arith(@FIELD+2)
#endif

#proc areadef
	xrange: @MINTIME @MAXTIME
	#if $def(AVERAGES) = 1 && @SD = 1
		yautorange: datafields=@FIELD,@HIGHFIELD lowfix=0 incmult=1.5 selectrows=@1 <= @MAXTIME && @1 >= @MINTIME
	#else
		yautorange: datafields=@FIELD lowfix=0 incmult=1.5 selectrows=@1 <= @MAXTIME && @1 >= @MINTIME
	#endif
	rectangle: 0.5 @Y1 8.0 @Y2
	
#proc xaxis
	selflocatingstubs: list @XTICS
	stubhide: yes
	#if @GRAPH = 1
	stubhide: no
	label: time (@XUNITS)
	#endif
	ticlen: 0.05 0.05
	#set MTINC = $defaultinc(@MINTIME,@MAXTIME)
	#set MTINC = $arith(@MTINC/5)
	minortics: yes
	minorticinc: @MTINC
	minorticlen: 0.03 0.03
	grid: color=gray(0.8)
	gridskip: minmax
	stubdetails: size=7

#proc yaxis
	stubs: inc
	stubdetails: adjust=0.1,0 size=7
	ticlen: 0.04 0
	minorticlen: 0.03 0
	grid: color=gray(0.8)
	gridskip: minmax

#proc yaxis
	stubs: inc
	stubdetails: adjust=0.2,0 align=left size=7
	ticlen: 0 0.04
	minorticlen: 0 0.03	
	location: 8.0

#if $def(AVERAGES) = 1 && @SD = 1
	#proc rangesweep
		xfield: @1
		lofield: @LOWFIELD
		hifield: @HIGHFIELD
		color: pink
#endif

#proc lineplot
	xfield: @1
	yfield: @FIELD
	#set COLOR = $icolor(@GRAPH)
	linedetails: width=0.6 color=@COLOR style=0
	
#proc annotate
	#set Y = $arith(@GHEIGHT/2)
	#set Y = $arith(@Y1+@Y)
	location: 7.9 @Y
	textdetails: align=right size=9
	text: @TITLE

#set GRAPH = $arith(@GRAPH+1)
#if $def(AVERAGES) = 1
	#set FIELD = $arith(@FIELD+3)
#else
	#set FIELD = $arith(@FIELD+1)
#endif
#endloop

#proc xaxis
	selflocatingstubs: list @XTICS
	ticlen: 0.05 0.05
	#set MTINC = $defaultinc(@MINTIME,@MAXTIME)
	#set MTINC = $arith(@MTINC/5)
	minortics: yes
	minorticinc: @MTINC
	minorticlen: 0.03 0.03
	location: @Y2
	stubdetails: adjust=0,0.25 size=7

#proc annotate
	#set Y = $arith(@HEIGHT/2)
	location: @YLABELDISTANCE @Y
	textdetails: align=center
	verttext: yes
	text: @YLABEL
